#
# spec file for package raptor
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           raptor
Version:        2.0.15
Release:        lp152.4.3.1
Summary:        RDF Parser Toolkit
License:        LGPL-2.1-or-later OR GPL-2.0-or-later OR Apache-2.0
Group:          System/Libraries
URL:            http://librdf.org/raptor/
Source0:        http://download.librdf.org/source/%{name}2-%{version}.tar.gz
Source1:        http://download.librdf.org/source/raptor2-%{version}.tar.gz.asc
Source2:        %{name}.keyring
Source3:        baselibs.conf
Patch1:         https://raw.githubusercontent.com/LibreOffice/core/master/external/redland/raptor/0001-Calcualte-max-nspace-declarations-correctly-for-XML-.patch.1
Patch2:         https://raw.githubusercontent.com/LibreOffice/core/master/external/redland/raptor/ubsan.patch
BuildRequires:  bison
BuildRequires:  curl-devel
BuildRequires:  libicu-devel
BuildRequires:  libxslt-devel
BuildRequires:  pkgconfig
%if !0%{?sles_version}
BuildRequires:  pkgconfig(libxml-2.0)
%else
BuildRequires:  libxml2-devel
%endif

%description
Raptor is the RDF Parser Toolkit for Redland that provides a set of
standalone RDF parsers, generating triples from RDF/XML or N-Triples.

%package -n libraptor2-0
Summary:        RDF Parser Toolkit
Group:          System/Libraries

%description -n libraptor2-0
Raptor is the RDF Parser Toolkit for Redland that provides a set of
standalone RDF parsers, generating triples from RDF/XML or N-Triples.

%package -n libraptor-devel
Summary:        Development package for the raptor library
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libraptor2-0 = %{version}
Requires:       raptor = %{version}
Provides:       raptor-devel = %{version}
Obsoletes:      raptor-devel < %{version}

%description -n libraptor-devel
This package contains the files needed to compile programs that use the
raptor library.

%prep
%setup -q -n %{name}2-%{version}
%patch1 -p1
%patch2

%build
%configure \
	--disable-gtk-doc \
	--disable-static \
	--with-pic \
	--with-icu-config=%{_bindir}/icu-config \
	--with-html-dir=%{_docdir}
%make_build

%install
%make_install
mv %{buildroot}%{_docdir}/raptor2 %{buildroot}%{_docdir}/raptor-devel
#causes some ugly  dependency bloat..
rm -f %{buildroot}%{_libdir}/libraptor2.la

%check
export MALLOC_CHECK_=2
make check
unset MALLOC_CHECK_

%post -n libraptor2-0 -p /sbin/ldconfig
%postun -n libraptor2-0 -p /sbin/ldconfig

%files
%license COPYING COPYING.LIB LICENSE.txt
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/rapper
%{_mandir}/man?/*

%files -n libraptor-devel
%doc %{_docdir}/raptor-devel
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc

%files -n libraptor2-0
%{_libdir}/libraptor2.so.0*

%changelog
* Tue Nov 10 2020 Dirk Mueller <dmueller@suse.com>
- add 0001-Calcualte-max-nspace-declarations-correctly-for-XML-.patch.1,
  ubsan.patch (bsc#1178593, CVE-2017-18926)
* Sun Apr 26 2015 mpluskal@suse.com
- Add gpg signature
- Update dependencies
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 2.0.15
  * Made several fixes to Turtle / N-Triples family of parsers and serializers
  * Added utility functions for re-entrant sorting of objects and sequences.
  * Made other fixes and improvements including fixing reported issues:
    0000574, 0000575, 0000576, 0000577, 0000579, 0000581 and 0000584.
* Sat Sep 14 2013 hrvoje.senjan@gmail.com
- Update to version 2.0.10
  * Completed support for Turtle Terse RDF Triple Language W3C Candidate
  Recommendation 19 February 2013 (Turtle 2013)
  * Added support for N-Triples W3C Working Group Note 09 April 2013
  (N-Triples 2013)
  * Added a few new Turtle and N-Triples support functions
  * Update configure to better handle mixed pkg-config settings
  * Fixed reported issues: 0000532, 0000535, 0000545 and 0000548
* Thu May 30 2013 tittiatcoke@gmail.com
- Update to version 2.0.9
  * Added full parsing and serializing support for Turtle Terse RDF
    Triple Language W3C Candidate Recommendation 19 February 2013
  * Added CMake build framework for building Raptor on Microsoft
  * Made a few minor fixes and improvements
  * Fixed reported issues: 0000499, 0000508, 0000520, 0000521
    and 0000526
* Fri Apr  5 2013 idonmez@suse.com
- Update Source URL, see https://en.opensuse.org/SourceUrls
* Tue Nov 20 2012 cgiboudeaux@gmx.com
- Fix build on SLES: pkgconfig(libxml-2.0) fails
* Mon Jul 16 2012 cfarrell@suse.com
- license update: LGPL-2.1+ or GPL-2.0+ or Apache-2.0
  Updating to those licenses stated in the LICENSE.txt file (even though
  the LGPL-2.1 has a migration clause to GPL-2.0 anyway"
* Thu Jun 28 2012 mlin@suse.com
- Update to version 2.0.8
  * Added support for RDFa 1.1 via updated librdfa
  * Multiple portability fixes for Windows and Solarises. (Daniel Richard G.)
  * Multiple minor fixes and improvements
  * Fixed reported issues: 0000381, 0000487, 0000505 and 0000507
* Fri Apr  6 2012 tittiatcoke@gmail.com
- Update to v2.0.7
  * CVE-2012-0037 fixed (bnc#745298)
  * Removed Expat support
  * Removed internal Unicode NFC code for better and optional ICU
  * Added options for denying file requests and XML entity loading
  * Added options for SSL certificate verifying
* Wed Dec 21 2011 tittiatcoke@gmail.com
- Update to v2.0.6
  * Handle libCurl SSL options before 7.16.4 (2007)
  * Add a few sequence utility methods for sort, reverse and
    permute
  * All parsers and serializers use the W3C Format URIs as their
    primary URI
  * N-Quads parser can now handle optional context/graph URI
  * Turtle serializer uses official text/turtle mime type
  * Added some additional UTF-8 and snprintf utility functions
  * No longer needs math functions trunc, lround and round.
  * Several internal code style fixes and cleanups
* Sat Oct  1 2011 crrodriguez@opensuse.org
- Do not require gtk-doc to build
* Mon Sep 19 2011 tittiatcoke@gmail.com
- update to raptor2 v2.0.4
  + RDF/JSON parser now supports YAJL V2
  + Support libcurl 7.21.7 that removed the curl/types.h header
  + TRiG parser now supports the optional ':' in 'uri : { }' syntax
  + WWW module now supports setting SSL client side certificates
  + various bugfixes
  + see also http://librdf.org/raptor/RELEASE.html#rel2_0_4
* Thu Aug 11 2011 aj@suse.de
- Remove inclusion of <curl/types.h>, it's obsolete in curl since
  2004.
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
- removed package name from summary (fix for RPMLINT warning)
* Sat Apr 10 2010 davejplater@gmail.com
- Update to 1.4.21:
  This is a bug fix only release with no new features. New development
  has moved to raptor 2 where a planned ABI and API break is underway.
  RDFa parser buffer management problems were fixed.
  Turtle parser and serializer now use QNames correctly against
  specification
  RDF/XML parser now resets correctly to detect duplicate rdf:IDs
  Made a few other minor bug and build fixes
  Fixed reported issues: 0000318, 0000319, 0000326, 0000331, 0000332 and
  0000337
  See the Raptor 1.4.21 ChangeLog for the full details of the
  changes.
* Thu Dec  3 2009 dmueller@suse.de
- update to 1.4.20:
  Turtle serializing performance improvement by Chris Cannam
  librdfa RDFa parser updates to fix empty datatype, xml:lang and 1-char
  prefixes by Manu Sporny
  Fix a crash when the GRDDL parser reported errors
  Enable large file support for 32-bit systems
  Several resilience improvements by Lauri Aalto
  Other minor portability and bug fixes
  Fixed reported issues: 0000306 0000307 0000310 and 0000312.
* Mon Sep 15 2008 dmueller@suse.de
- fix -devel pckage requires
* Thu Jul 24 2008 dmueller@suse.de
- update to 1.4.18:
  Added an RDFa parser using an embedded version of librdfa by Manu
  Sporny of Digital Bazaar.
  Added an Atom 1.0 (RFC 4287) serializer with several output parameters.
  Improved RSS 1.0 serializer functionality and resilience.
  Added new API methods for qname, serializer, sequence and XML writer
  classes.
  Many other fixes and resilience improvements.
  Fixed reported issues: 0000186 and 0000255.
* Sun Apr  6 2008 crrodriguez@suse.de
- update to version 1.4.17
  * Added two new JSON serializers: resource-centric 'json'
  (Talis RDF/JSON) and triple-centric 'json-triples'
  * Added a new public XML SAX2 API class
  * Added a new error handling structure
  * Made the I/O Stream class support reading
  * Added several new API methods.
  * Made several fixes, portability and resilience improvements.
  * Fixed reported issues: 0000252 and 0000245.
* Wed Dec 19 2007 crrodriguez@suse.de
- missing pkg-config in buildrequires
* Sun Oct 28 2007 stbinner@suse.de
- update to version 1.4.16:
  * 100%% support for the GRDDL W3C Recommendation of 2007-09-11
  * Turtle parser and serializer were updated to support @base
  * Turtle and RDF/XML serializers had performance improvements
    for large graphs.
  * Added a TRiG Parser based on Turtle with named graph support.
  * Several other API changes, fixed and improvements were made.
  * Many other fixes and improvements.
* Tue Aug  7 2007 crrodriguez@suse.de
- as per http://lists.opensuse.org/opensuse-packaging/2007-07/msg00049.html
  taking manteniance of this package
- use system libcurl for web access
- use libxslt as well (adds grdd parser support)
- remove nasty la file that causes significant bloat
- Fix build and devel package dependencies (raptor.h only requires glibc-devel)
- remove static libraries
- run ldconfig correctly
- run make check on rpm check section.
* Fri May  4 2007 dmueller@suse.de
- libraptor -> libraptor1
* Thu May  3 2007 lrupp@suse.de
- libraptor1-devel -> libraptor-devel
* Thu May  3 2007 lrupp@suse.de
- add Provides/Obsoletes: raptor-devel
* Wed May  2 2007 wstephenson@suse.de
- updated to version 1.4.15:
  * Mostly pass GRDDL W3C Working Draft 2 March 2007 parser test suite
  * Turtle parser was changed to accept the N3 mime type text/rdf+n3
    at low Q(quality) so it might work for N3 that is the RDF subset.
  * Changed the RSS Tag Soup parser and RSS 1.0 serializer to stop
    sharing use of the declared namespaces so that when using both
    at the same time, there is no double-free of the same objects.
  * Correct the content: namespace URI in the RSS parser and serializers.
  * rapper gains a -t/--trace option to show URIs traversed.
  * raptor_uri_resolve_uri_reference() buffer overrun fixed
  * Enhanced XML error message reporting
- version 1.4.14:
  * Added a Turtle Terse RDF Triple Language serialiser by Dave Robillard
    based on the existing RDF/XML-Abbrev serialiser.
  * Added a GraphViz DOT format serialiser by Evan Nemerson.
  * The GRDDL parser now does namespace and profile URI recursion and
    has other improvements and fixes.
  * The libxml minimum version is now 2.6.8
- version 1.4.13:
  * Prevent losing memory for a raptor_xml_writer when a serializer
    is reused several times.
  * Fixed Issue#0000134: Check for equal scheme and authority during
    construction of relative URIs from two absolute URIs, from the
    Redland Issue Tracker.
* Thu Oct 12 2006 tiwai@suse.de
- updated to version 1.4.12:
  * Make serialization order compatible with 1.4.10
  * Added raptor_get_feature_count()
  * Added raptor_www_set_uri_filter()
  * Fixed raptor_namespaces_qname_from_uri to be public
  * Fix misc bugs
* Wed Aug 23 2006 tiwai@suse.de
- updated to version 1.4.10:
  * Fixed crash with RSS Tag Soup parser generating triples too late
  * Fixed a crash with the RDF/XML parser
  * Parsers no longer generate any triple parts of type
    RAPTOR_IDENTIFIER_TYPE_ORDINAL
- remove -fno-strict-aliasing.
* Mon May 15 2006 tiwai@suse.de
- updated to version 1.4.9.
  * new tutorial documents
  * fixes for 64bit systems
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 1.4.4.
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 1.3.2.
* Thu Feb 26 2004 tiwai@suse.de
- updated to version 1.2.0.
* Tue Jan 13 2004 tiwai@suse.de
- build as non-root.
* Fri Jan  9 2004 tiwai@suse.de
- updated to version 1.1.0.
* Mon Aug 18 2003 tiwai@suse.de
- fixed the invalid use of va_list.
* Fri Jun  6 2003 tiwai@suse.de
- updated to version 0.9.10.
* Wed Apr  2 2003 tiwai@suse.de
- initial version: 0.9.9.
